@@ -1,4 +1,8 @@
-VER_SOCKS5 = 5
+# Copyright (c) Aaron Gallagher <_@habnab.it>
+# See COPYING for details.
+
+VER_SOCKS4, VER_SOCKS5 = 4, 5
+AUTH_ANONYMOUS, AUTH_LOGIN = '\x00', '\x02'
 ATYP_IPV4, ATYP_DOMAINNAME, ATYP_IPV6 = 1, 3, 4
 CMD_CONNECT, CMD_BIND, CMD_UDP_ASSOCIATE = 1, 2, 3
 NO_ACCEPTABLE_METHODS = 255
@@ -8,3 +12,6 @@ SOCKS5_GRANTED, SOCKS5_GENERAL_FAILURE, SOCKS5_REJECTED = 0, 1, 2
 SOCKS5_NETWORK_UNREACHABLE, SOCKS5_HOST_UNREACHABLE = 3, 4
 SOCKS5_CONNECTION_REFUSED, SOCKS5_TTL_EXPIRED = 5, 6
 SOCKS5_COMMAND_NOT_SUPPORTED, SOCKS5_ADDRESS_NOT_SUPPORTED = 7, 8
+
+SOCKS4_GRANTED, SOCKS4_REJECTED_OR_FAILED = 0x5a, 0x5b
+SOCKS4_IDENTD_UNREACHABLE, SOCKS4_IDENTD_MISMATCH = 0x5c, 0x5d
